
# Slot: downloadURL




URI: [biolink:downloadURL](https://w3id.org/biolink/vocab/downloadURL)

## Domain and Range

[DistributionLevel](DistributionLevel.md) ->  <sub>OPT</sub> [String](String.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [DistributionLevel](DistributionLevel.md)
